@@ -1,5 +1,5 @@
 /* 
- * $Id: citserver.c 8080 2009-11-24 20:19:06Z ajc $
+ * $Id: citserver.c 8324 2010-02-17 20:03:28Z ajc $
  *
  * Main source module for the Citadel server
  *
@@ -1043,12 +1043,11 @@ void do_command_loop(void) {
 	}
 
 	/* Log the server command, but don't show passwords... */
-	if ( (strncasecmp(cmdbuf, "PASS", 4))
-	   && (strncasecmp(cmdbuf, "SETP", 4)) ) {
+	if ( (strncasecmp(cmdbuf, "PASS", 4)) && (strncasecmp(cmdbuf, "SETP", 4)) ) {
 		CtdlLogPrintf(CTDL_INFO, "%s\n", cmdbuf);
 	}
 	else {
-		CtdlLogPrintf(CTDL_INFO, "<password command sent>\n");
+		CtdlLogPrintf(CTDL_INFO, "<password command hidden from log>\n");
 	}
 
 	buffer_output();
@@ -1123,5 +1122,5 @@ CTDL_MODULE_INIT(citserver)
 		CtdlRegisterProtoHook(cmd_time, "TIME", "fetch the date and time from the server");
 	}
         /* return our Subversion id for the Log */
-	return "$Id: citserver.c 8080 2009-11-24 20:19:06Z ajc $";
+	return "$Id: citserver.c 8324 2010-02-17 20:03:28Z ajc $";
 }
