@@ -1,5 +1,5 @@
 /* 
- * $Id: file_ops.c 6957 2009-01-16 20:33:00Z ajc $
+ * $Id: file_ops.c 8001 2009-11-03 12:15:17Z davew $
  *
  * Server functions which handle file transfers and room directories.
  *
@@ -45,6 +45,8 @@
 #include "snprintf.h"
 #endif
 
+#include "ctdl_module.h"
+
 /*
  * network_talking_to()  --  concurrency checker
  */
@@ -161,6 +163,7 @@ void cmd_movf(char *cmdbuf)
 	char buf[PATH_MAX];
 	int a;
 	struct ctdlroom qrbuf;
+	int rv = 0;
 
 	extract_token(filename, cmdbuf, 0, '|', sizeof filename);
 	extract_token(newroom, cmdbuf, 1, '|', sizeof newroom);
@@ -192,7 +195,7 @@ void cmd_movf(char *cmdbuf)
 		return;
 	}
 
-	if (getroom(&qrbuf, newroom) != 0) {
+	if (CtdlGetRoom(&qrbuf, newroom) != 0) {
 		cprintf("%d '%s' does not exist.\n", ERROR + ROOM_NOT_FOUND, newroom);
 		return;
 	}
@@ -214,7 +217,7 @@ void cmd_movf(char *cmdbuf)
 	snprintf(buf, sizeof buf,
 		 "cat ./files/%s/filedir |grep \"%s\" >>./files/%s/filedir",
 		 CC->room.QRdirname, filename, qrbuf.QRdirname);
-	system(buf);
+	rv = system(buf);
 	cprintf("%d File '%s' has been moved.\n", CIT_OK, filename);
 }
 
@@ -305,6 +308,7 @@ void cmd_oimg(char *cmdbuf)
 	char which_user[USERNAME_SIZE];
 	int which_floor;
 	int a;
+	int rv;
 
 	extract_token(filename, cmdbuf, 0, '|', sizeof filename);
 
@@ -322,7 +326,7 @@ void cmd_oimg(char *cmdbuf)
 
 	if (!strcasecmp(filename, "_userpic_")) {
 		extract_token(which_user, cmdbuf, 1, '|', sizeof which_user);
-		if (getuser(&usbuf, which_user) != 0) {
+		if (CtdlGetUser(&usbuf, which_user) != 0) {
 			cprintf("%d No such user.\n",
 				ERROR + NO_SUCH_USER);
 			return;
@@ -361,7 +365,7 @@ void cmd_oimg(char *cmdbuf)
 			ERROR + FILE_NOT_FOUND, pathname, strerror(errno));
 		return;
 	}
-	fread(&MimeTestBuf[0], 1, 32, CC->download_fp);
+	rv = fread(&MimeTestBuf[0], 1, 32, CC->download_fp);
 	rewind (CC->download_fp);
 	OpenCmdResult(pathname, GuessMimeType(&MimeTestBuf[0], 32));
 }
@@ -516,7 +520,7 @@ void cmd_uimg(char *cmdbuf)
 /*
  * close the download file
  */
-void cmd_clos(void)
+void cmd_clos(char *cmdbuf)
 {
 	char buf[256];
 
@@ -545,7 +549,7 @@ void cmd_clos(void)
 /*
  * abort an upload
  */
-void abort_upl(struct CitContext *who)
+void abort_upl(CitContext *who)
 {
 	if (who->upload_fp != NULL) {
 		fclose(who->upload_fp);
@@ -648,6 +652,7 @@ void cmd_writ(char *cmdbuf)
 {
 	int bytes;
 	char *buf;
+	int rv;
 
 	unbuffer_output();
 
@@ -667,7 +672,7 @@ void cmd_writ(char *cmdbuf)
 	cprintf("%d %d\n", SEND_BINARY, bytes);
 	buf = malloc(bytes + 1);
 	client_read(buf, bytes);
-	fwrite(buf, bytes, 1, CC->upload_fp);
+	rv = fwrite(buf, bytes, 1, CC->upload_fp);
 	free(buf);
 }
 
@@ -769,3 +774,28 @@ void cmd_nuop(char *cmdbuf)
 	CC->upload_type = UPL_NET;
 	cprintf("%d Ok\n", CIT_OK);
 }
+
+
+/*****************************************************************************/
+/*                      MODULE INITIALIZATION STUFF                          */
+/*****************************************************************************/
+
+CTDL_MODULE_INIT(file_ops)
+{
+	if (!threading) {
+		CtdlRegisterProtoHook(cmd_delf, "DELF", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_movf, "MOVF", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_open, "OPEN", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_clos, "CLOS", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_uopn, "UOPN", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_ucls, "UCLS", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_read, "READ", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_writ, "WRIT", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_oimg, "OIMG", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_ndop, "NDOP", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_nuop, "NUOP", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_uimg, "UIMG", "Autoconverted. TODO: document me.");
+	}
+        /* return our Subversion id for the Log */
+	return "$Id: file_ops.c 8001 2009-11-03 12:15:17Z davew $";
+}
