@@ -1,5 +1,5 @@
 /*
- * $Id: internet_addressing.c 7011 2009-01-28 04:46:51Z ajc $
+ * $Id: internet_addressing.c 7954 2009-10-24 23:23:27Z davew $
  *
  * This file contains functions which handle the mapping of Internet addresses
  * to users on the Citadel system.
@@ -44,6 +44,7 @@
 #include "parsedate.h"
 #include "database.h"
 
+#include "ctdl_module.h"
 
 #ifndef HAVE_SNPRINTF
 #include "snprintf.h"
@@ -899,7 +900,7 @@ void CtdlDirectoryAddUser(char *internet_addr, char *citadel_addr) {
 	char key[SIZ];
 
 	if (IsDirectory(internet_addr, 0) == 0) return;
-	CtdlLogPrintf(CTDL_DEBUG, "Dir: %s --> %s\n", internet_addr, citadel_addr);
+	CtdlLogPrintf(CTDL_DEBUG, "Create directory entry: %s --> %s\n", internet_addr, citadel_addr);
 	directory_key(key, internet_addr);
 	cdb_store(CDB_DIRECTORY, key, strlen(key), citadel_addr, strlen(citadel_addr)+1 );
 }
@@ -914,6 +915,7 @@ void CtdlDirectoryAddUser(char *internet_addr, char *citadel_addr) {
 void CtdlDirectoryDelUser(char *internet_addr, char *citadel_addr) {
 	char key[SIZ];
 
+	CtdlLogPrintf(CTDL_DEBUG, "Delete directory entry: %s --> %s\n", internet_addr, citadel_addr);
 	directory_key(key, internet_addr);
 	cdb_delete(CDB_DIRECTORY, key, strlen(key) );
 }
