@@ -1,9 +1,24 @@
 /*
- * $Id: imap_fetch.c 7522 2009-06-01 16:44:38Z ajc $
+ * $Id: imap_fetch.c 8060 2009-11-18 15:35:41Z ajc $
  *
  * Implements the FETCH command in IMAP.
  * This is a good example of the protocol's gratuitous complexity.
  *
+ * Copyright (c) 2001-2009 by the citadel.org team
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 
@@ -39,7 +54,6 @@
 #include "citserver.h"
 #include "support.h"
 #include "config.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
@@ -87,6 +101,7 @@ void imap_fetch_flags(int seq) {
 	cprintf(")");
 }
 
+
 void imap_fetch_internaldate(struct CtdlMessage *msg) {
 	char buf[SIZ];
 	time_t msgdate;
@@ -175,7 +190,8 @@ void imap_fetch_rfc822(long msgnum, char *whichfmt) {
 		CC->redirect_alloc = SIZ;
 		CtdlOutputMsg(msgnum, MT_RFC822,
 			(need_body ? HEADERS_ALL : HEADERS_FAST),
-			      0, 1, NULL, 0);
+			0, 1, NULL, SUPPRESS_ENV_TO
+		);
 		if (!need_body) cprintf("\r\n");	/* extra trailing newline */
 		IMAP->cached_rfc822_data = CC->redirect_buffer;
 		IMAP->cached_rfc822_len = CC->redirect_len;
@@ -591,7 +607,8 @@ void imap_fetch_body(long msgnum, char *item, int is_peek) {
 	}
 	CtdlLogPrintf(CTDL_DEBUG, "Section is: %s%s\n", 
 		section, 
-		IsEmptyStr(section) ? "(empty)" : "");
+		IsEmptyStr(section) ? "(empty)" : ""
+	);
 
 	/* Burn the cache if we don't have the same section of the 
 	 * same message again.
@@ -640,11 +657,11 @@ void imap_fetch_body(long msgnum, char *item, int is_peek) {
 	}
 
 	else if ( (!strcmp(section, "1")) && (msg->cm_format_type != 4) ) {
-		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_NONE, 0, 1, 0);
+		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_NONE, 0, 1, SUPPRESS_ENV_TO);
 	}
 
 	else if (!strcmp(section, "")) {
-		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_ALL, 0, 1, 0);
+		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_ALL, 0, 1, SUPPRESS_ENV_TO);
 	}
 
 	/*
@@ -656,7 +673,7 @@ void imap_fetch_body(long msgnum, char *item, int is_peek) {
 		 * IMAP library and this broke Mail.App and iPhone Mail, so we had to change it
 		 * to HEADERS_ONLY so the trendy hipsters with their iPhones can read mail.
 		 */
-		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_ONLY, 0, 1, 0);
+		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_ONLY, 0, 1, SUPPRESS_ENV_TO);
 		imap_strip_headers(section);
 	}
 
@@ -664,7 +681,7 @@ void imap_fetch_body(long msgnum, char *item, int is_peek) {
 	 * Strip it down if the client asked for everything _except_ headers.
 	 */
 	else if (!strncasecmp(section, "TEXT", 4)) {
-		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_NONE, 0, 1, 0);
+		CtdlOutputPreLoadedMsg(msg, MT_RFC822, HEADERS_NONE, 0, 1, SUPPRESS_ENV_TO);
 	}
 
 	/*
@@ -908,7 +925,7 @@ void imap_fetch_bodystructure (long msgnum, char *item,
 		CC->redirect_buffer = malloc(SIZ);
 		CC->redirect_len = 0;
 		CC->redirect_alloc = SIZ;
-		CtdlOutputPreLoadedMsg(msg, MT_RFC822, 0, 0, 1, 0);
+		CtdlOutputPreLoadedMsg(msg, MT_RFC822, 0, 0, 1, SUPPRESS_ENV_TO);
 		rfc822 = CC->redirect_buffer;
 		rfc822_len = CC->redirect_len;
 		CC->redirect_buffer = NULL;
@@ -1268,7 +1285,6 @@ void imap_pick_range(char *supplied_range, int is_uid) {
 			}
 		}
 	}
-
 }
 
 
