@@ -1,10 +1,29 @@
 /*
- * $Id: imap_search.c 6628 2008-09-25 16:29:49Z ajc $
+ * $Id: imap_search.c 7956 2009-10-25 00:26:06Z davew $
  *
  * Implements IMAP's gratuitously complex SEARCH command.
  *
+ *
+ * Copyright (c) 2001-2009 by the citadel.org team
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "ctdl_module.h"
+
+
 #include "sysdep.h"
 #include <stdlib.h>
 #include <unistd.h>
@@ -37,7 +56,6 @@
 #include "citserver.h"
 #include "support.h"
 #include "config.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
