@@ -1,10 +1,22 @@
 /*
- * $Id: serv_xmpp.c 7390 2009-04-22 14:39:23Z ajc $ 
+ * $Id: serv_xmpp.c 7921 2009-10-17 12:21:17Z davew $ 
  *
  * XMPP (Jabber) service for the Citadel system
- * Copyright (c) 2007 by Art Cancro
- * This code is released under the terms of the GNU General Public License.
+ * Copyright (c) 2007-2009 by Art Cancro
  *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "sysdep.h"
@@ -39,7 +51,6 @@
 #include "citserver.h"
 #include "support.h"
 #include "config.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
@@ -421,6 +432,8 @@ void xmpp_greeting(void) {
 	XML_SetElementHandler(XMPP->xp, xmpp_xml_start, xmpp_xml_end);
 	XML_SetCharacterDataHandler(XMPP->xp, xmpp_xml_chardata);
 	// XML_SetUserData(XMPP->xp, something...);
+
+	CC->can_receive_im = 1;		/* This protocol is capable of receiving instant messages */
 }
 
 
@@ -490,5 +503,5 @@ CTDL_MODULE_INIT(jabber)
 	}
 
 	/* return our Subversion id for the Log */
-	return "$Id: serv_xmpp.c 7390 2009-04-22 14:39:23Z ajc $";
+	return "$Id: serv_xmpp.c 7921 2009-10-17 12:21:17Z davew $";
 }
