@@ -1,12 +1,25 @@
 /*
- * $Id: xmpp_sasl_service.c 7094 2009-02-11 01:46:19Z ajc $ 
+ * $Id: xmpp_sasl_service.c 8035 2009-11-10 20:00:25Z davew $ 
  *
  * Barebones SASL authentication service for XMPP (Jabber) clients.
  *
  * Note: RFC3920 says we "must" support DIGEST-MD5 but we only support PLAIN.
  *
- * Copyright (c) 2007 by Art Cancro
- * This code is released under the terms of the GNU General Public License.
+ * Copyright (c) 2007-2009 by Art Cancro
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
 
@@ -62,6 +75,7 @@ int xmpp_auth_plain(char *authstring)
 
 
 	/* Take apart the authentication string */
+	memset(pass, 0, sizeof(pass));
 
 	CtdlDecodeBase64(decoded_authstring, authstring, strlen(authstring));
 	safestrncpy(ident, decoded_authstring, sizeof ident);
@@ -116,7 +130,7 @@ void xmpp_sasl_auth(char *sasl_auth_mech, char *authstring) {
 		return;
 	}
 
-        if (CC->logged_in) logout();  /* Client may try to log in twice.  Handle this. */
+        if (CC->logged_in) CtdlUserLogout();  /* Client may try to log in twice.  Handle this. */
 
 	if (CC->nologin) {
 		cprintf("<failure xmlns=\"urn:ietf:params:xml:ns:xmpp-sasl\">");
@@ -143,7 +157,7 @@ void xmpp_sasl_auth(char *sasl_auth_mech, char *authstring) {
 void jabber_non_sasl_authenticate(char *iq_id, char *username, char *password, char *resource) {
 	int result;
 
-        if (CC->logged_in) logout();  /* Client may try to log in twice.  Handle this. */
+        if (CC->logged_in) CtdlUserLogout();  /* Client may try to log in twice.  Handle this. */
 
 	result = CtdlLoginExistingUser(NULL, username);
 	if (result == login_ok) {
