@@ -1,10 +1,23 @@
 /*
- * $Id: serv_listsub.c 6146 2008-03-21 21:42:54Z davew $
+ * $Id: serv_listsub.c 7921 2009-10-17 12:21:17Z davew $
  *
  * This module handles self-service subscription/unsubscription to mail lists.
  *
- * Copyright (C) 2002-2005 by Art Cancro and others.
- * This code is released under the terms of the GNU General Public License.
+ * Copyright (c) 2002-2009 by the citadel.org team
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
 
@@ -39,7 +52,6 @@
 #include "citserver.h"
 #include "support.h"
 #include "config.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
@@ -93,7 +105,7 @@ void do_subscribe(char *room, char *email, char *subtype, char *webpage) {
 	char scanemail[256];
 	int found_sub = 0;
 
-	if (getroom(&qrbuf, room) != 0) {
+	if (CtdlGetRoom(&qrbuf, room) != 0) {
 		cprintf("%d There is no list called '%s'\n", ERROR + ROOM_NOT_FOUND, room);
 		return;
 	}
@@ -233,7 +245,7 @@ void do_unsubscribe(char *room, char *email, char *webpage) {
 	char scanemail[256];
 	int found_sub = 0;
 
-	if (getroom(&qrbuf, room) != 0) {
+	if (CtdlGetRoom(&qrbuf, room) != 0) {
 		cprintf("%d There is no list called '%s'\n",
 			ERROR + ROOM_NOT_FOUND, room);
 		return;
@@ -382,7 +394,7 @@ void do_confirm(char *room, char *token) {
 
 	strcpy(address_to_unsubscribe, "");
 
-	if (getroom(&qrbuf, room) != 0) {
+	if (CtdlGetRoom(&qrbuf, room) != 0) {
 		cprintf("%d There is no list called '%s'\n",
 			ERROR + ROOM_NOT_FOUND, room);
 		return;
@@ -576,5 +588,5 @@ CTDL_MODULE_INIT(listsub)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_listsub.c 6146 2008-03-21 21:42:54Z davew $";
+	return "$Id: serv_listsub.c 7921 2009-10-17 12:21:17Z davew $";
 }
