@@ -1,5 +1,5 @@
 /*
- * $Id: serv_mrtg.c 6409 2008-06-25 21:08:59Z ajc $
+ * $Id: serv_mrtg.c 7921 2009-10-17 12:21:17Z davew $
  *
  * This module supplies statistics about the activity levels of your Citadel
  * system.  We didn't bother writing a reporting module, because there is
@@ -7,6 +7,21 @@
  * is available at http://www.mrtg.org that can fetch data using external
  * scripts.  This module supplies data in the format expected by MRTG.
  *
+ * Copyright (c) 1987-2009 by the citadel.org team
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "sysdep.h"
@@ -40,7 +55,6 @@
 #include "support.h"
 #include "config.h"
 #include "control.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
@@ -171,5 +185,5 @@ CTDL_MODULE_INIT(mrtg)
 	}
 	
 	/* return our Subversion id for the Log */
-        return "$Id: serv_mrtg.c 6409 2008-06-25 21:08:59Z ajc $";
+        return "$Id: serv_mrtg.c 7921 2009-10-17 12:21:17Z davew $";
 }
