@@ -1,8 +1,23 @@
 /*
- * $Id: serv_notes.c 6630 2008-09-26 16:02:27Z ajc $
+ * $Id: serv_notes.c 7921 2009-10-17 12:21:17Z davew $
  *
  * Handles functions related to yellow sticky notes.
  *
+ * Copyright (c) 2007-2009 by the citadel.org team
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "sysdep.h"
@@ -35,7 +50,6 @@
 #include "citserver.h"
 #include "support.h"
 #include "config.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
@@ -172,5 +186,5 @@ CTDL_MODULE_INIT(notes)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_notes.c 6630 2008-09-26 16:02:27Z ajc $";
+	return "$Id: serv_notes.c 7921 2009-10-17 12:21:17Z davew $";
 }
