@@ -1,5 +1,5 @@
 /*
- * $Id: serv_smtp.c 7232 2009-03-19 14:22:27Z ajc $
+ * $Id: serv_smtp.c 8050 2009-11-14 16:17:06Z davew $
  *
  * This module is an SMTP and ESMTP implementation for the Citadel system.
  * It is compliant with all of the following:
@@ -22,6 +22,21 @@
  * The VRFY and EXPN commands have been removed from this implementation
  * because nobody uses these commands anymore, except for spammers.
  *
+ * Copyright (c) 1998-2009 by the citadel.org team
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "sysdep.h"
@@ -60,7 +75,6 @@
 #include "support.h"
 #include "config.h"
 #include "control.h"
-#include "room_ops.h"
 #include "user_ops.h"
 #include "policy.h"
 #include "database.h"
@@ -108,6 +122,7 @@ enum {				/* Command states for login authentication */
 
 int run_queue_now = 0;	/* Set to 1 to ignore SMTP send retry times */
 
+citthread_mutex_t smtp_send_lock;
 
 
 /*****************************************************************************/
@@ -316,6 +331,7 @@ void smtp_get_user(char *argbuf) {
 void smtp_get_pass(char *argbuf) {
 	char password[SIZ];
 
+	memset(password, 0, sizeof(password));	
 	CtdlDecodeBase64(password, argbuf, SIZ);
 	/* CtdlLogPrintf(CTDL_DEBUG, "Trying <%s>\n", password); */
 	if (CtdlTryPassword(password) == pass_ok) {
@@ -659,15 +675,27 @@ void smtp_data(void) {
 	datestring(nowstamp, sizeof nowstamp, time(NULL), DATESTRING_RFC822);
 	body = malloc(4096);
 
-	if (body != NULL) snprintf(body, 4096,
-		"Received: from %s (%s [%s])\n"
-		"	by %s; %s\n",
-			SMTP->helo_node,
-			CC->cs_host,
-			CC->cs_addr,
-			config.c_fqdn,
-			nowstamp);
-	
+	if (body != NULL) {
+		if (SMTP->is_lmtp && (CC->cs_UDSclientUID != -1)) {
+			snprintf(body, 4096,
+				 "Received: from %s (Citadel from userid %ld)\n"
+				 "	by %s; %s\n",
+				 SMTP->helo_node,
+				 (long int) CC->cs_UDSclientUID,
+				 config.c_fqdn,
+				 nowstamp);
+		}
+		else {
+			snprintf(body, 4096,
+				 "Received: from %s (%s [%s])\n"
+				 "	by %s; %s\n",
+				 SMTP->helo_node,
+				 CC->cs_host,
+				 CC->cs_addr,
+				 config.c_fqdn,
+				 nowstamp);
+		}
+	}
 	body = CtdlReadMessageBody(".", config.c_maxmsglen, body, 1, 0);
 	if (body == NULL) {
 		cprintf("550 Unable to save message: internal error.\r\n");
@@ -1689,38 +1717,63 @@ void smtp_do_procmsg(long msgnum, void *userdata) {
 
 
 
+
 /*
  * smtp_do_queue()
  * 
  * Run through the queue sending out messages.
  */
-void smtp_do_queue(void) {
-	static int doing_queue = 0;
+void *smtp_do_queue(void *arg) {
 	int num_processed = 0;
+	struct CitContext smtp_queue_CC;
 
-	/*
-	 * This is a simple concurrency check to make sure only one queue run
-	 * is done at a time.  We could do this with a mutex, but since we
-	 * don't really require extremely fine granularity here, we'll do it
-	 * with a static variable instead.
-	 */
-	if (doing_queue) return;
-	doing_queue = 1;
-
-	/* 
-	 * Go ahead and run the queue
-	 */
 	CtdlLogPrintf(CTDL_INFO, "SMTP client: processing outbound queue\n");
 
-	if (getroom(&CC->room, SMTP_SPOOLOUT_ROOM) != 0) {
-		CtdlLogPrintf(CTDL_ERR, "Cannot find room <%s>\n", SMTP_SPOOLOUT_ROOM);
-		return;
-	}
-	num_processed = CtdlForEachMessage(MSGS_ALL, 0L, NULL, SPOOLMIME, NULL, smtp_do_procmsg, NULL);
+	CtdlFillSystemContext(&smtp_queue_CC, "SMTP Send");
+	citthread_setspecific(MyConKey, (void *)&smtp_queue_CC );
 
+	if (CtdlGetRoom(&CC->room, SMTP_SPOOLOUT_ROOM) != 0) {
+		CtdlLogPrintf(CTDL_ERR, "Cannot find room <%s>\n", SMTP_SPOOLOUT_ROOM);
+	}
+	else {
+		num_processed = CtdlForEachMessage(MSGS_ALL, 0L, NULL, SPOOLMIME, NULL, smtp_do_procmsg, NULL);
+	}
+
+	citthread_mutex_unlock (&smtp_send_lock);
 	CtdlLogPrintf(CTDL_INFO, "SMTP client: queue run completed; %d messages processed\n", num_processed);
-	run_queue_now = 0;
-	doing_queue = 0;
+	return(NULL);
+}
+
+
+
+/*
+ * smtp_queue_thread
+ *
+ * Create a thread to run the SMTP queue
+ *
+ * This was created as a response to a situation seen on Uncensored where a bad remote was holding
+ * up SMTP sending for long times.
+ * Converting to a thread does not fix the problem caused by the bad remote but it does prevent
+ * the SMTP sending from stopping housekeeping and the EVT_TIMER event system which in turn prevented
+ * other things from happening.
+ */
+void smtp_queue_thread (void)
+{
+	if (citthread_mutex_trylock (&smtp_send_lock)) {
+		CtdlLogPrintf(CTDL_DEBUG, "SMTP queue run already in progress\n");
+	}
+	else {
+		CtdlThreadCreate("SMTP Send", CTDLTHREAD_BIGSTACK, smtp_do_queue, NULL);
+	}
+}
+
+
+
+void smtp_server_going_down (void)
+{
+	CtdlLogPrintf(CTDL_DEBUG, "SMTP module clean up for shutdown.\n");
+
+	citthread_mutex_destroy (&smtp_send_lock);
 }
 
 
@@ -1776,15 +1829,15 @@ void smtp_init_spoolout(void) {
 	 * Create the room.  This will silently fail if the room already
 	 * exists, and that's perfectly ok, because we want it to exist.
 	 */
-	create_room(SMTP_SPOOLOUT_ROOM, 3, "", 0, 1, 0, VIEW_MAILBOX);
+	CtdlCreateRoom(SMTP_SPOOLOUT_ROOM, 3, "", 0, 1, 0, VIEW_MAILBOX);
 
 	/*
 	 * Make sure it's set to be a "system room" so it doesn't show up
 	 * in the <K>nown rooms list for Aides.
 	 */
-	if (lgetroom(&qrbuf, SMTP_SPOOLOUT_ROOM) == 0) {
+	if (CtdlGetRoomLock(&qrbuf, SMTP_SPOOLOUT_ROOM) == 0) {
 		qrbuf.QRflags2 |= QR2_SYSTEM;
-		lputroom(&qrbuf);
+		CtdlPutRoomLock(&qrbuf);
 	}
 }
 
@@ -1857,11 +1910,13 @@ CTDL_MODULE_INIT(smtp)
 					CitadelServiceSMTP_LMTP_UNF);
 
 		smtp_init_spoolout();
-		CtdlRegisterSessionHook(smtp_do_queue, EVT_TIMER);
+		CtdlRegisterSessionHook(smtp_queue_thread, EVT_TIMER);
 		CtdlRegisterSessionHook(smtp_cleanup_function, EVT_STOP);
 		CtdlRegisterProtoHook(cmd_smtp, "SMTP", "SMTP utility commands");
+		CtdlRegisterCleanupHook (smtp_server_going_down);
+		citthread_mutex_init (&smtp_send_lock, NULL);
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_smtp.c 7232 2009-03-19 14:22:27Z ajc $";
+	return "$Id: serv_smtp.c 8050 2009-11-14 16:17:06Z davew $";
 }
