@@ -1,9 +1,9 @@
 /*
- * $Id: serv_upgrade.c 7957 2009-10-25 01:07:14Z davew $
+ * $Id: serv_upgrade.c 8294 2010-02-09 21:09:19Z ajc $
  *
  * Transparently handle the upgrading of server data formats.
  *
- * Copyright (c) 1987-2009 by the citadel.org team
+ * Copyright (c) 1987-2010 by the citadel.org team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -265,17 +265,6 @@ void update_config(void) {
 		config.c_xmpp_s2s_port = 5269;
 	}
 
-	/* Erase LDAP config that might be left over from the old connector
-	 * which served a different purpose.
-	 */
-	if (CitControl.version < 760) {
-		strcpy(config.c_ldap_host, "");
-		config.c_ldap_port = 389;
-		strcpy(config.c_ldap_base_dn, "");
-		strcpy(config.c_ldap_bind_dn, "");
-		strcpy(config.c_ldap_bind_pw, "");
-	}
-
 	if (IsEmptyStr(config.c_default_cal_zone)) {
 		guess_time_zone();
 	}
@@ -335,5 +324,5 @@ CTDL_MODULE_UPGRADE(upgrade)
 	check_server_upgrades();
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_upgrade.c 7957 2009-10-25 01:07:14Z davew $";
+	return "$Id: serv_upgrade.c 8294 2010-02-09 21:09:19Z ajc $";
 }
