@@ -1,5 +1,5 @@
 /*
- * $Id: serv_wiki.c 8085 2009-11-25 20:38:42Z ajc $
+ * $Id: serv_wiki.c 8289 2010-02-09 19:42:25Z dothebart $
  *
  * Server-side module for Wiki rooms.  This handles things like version control. 
  * 
@@ -444,7 +444,7 @@ void wiki_rev_callback(char *name, char *filename, char *partnum, char *disp,
 					fprintf(fp, "%s\n", buf);
 				}
 			}
-		} while ((*ptr != 0) && ((int)ptr < ((int)content + length)));
+		} while ((*ptr != 0) && (ptr < ((char*)content + length)));
 		if (pclose(fp) != 0) {
 			CtdlLogPrintf(CTDL_ERR, "pclose() returned an error - patch failed\n");
 		}
@@ -663,5 +663,5 @@ CTDL_MODULE_INIT(wiki)
 	}
 
 	/* return our Subversion id for the Log */
-	return "$Id: serv_wiki.c 8085 2009-11-25 20:38:42Z ajc $";
+	return "$Id: serv_wiki.c 8289 2010-02-09 19:42:25Z dothebart $";
 }
