@@ -1,7 +1,7 @@
 /*
  * citserver's main() function lives here.
  *
- * $Id: server_main.c 7265 2009-03-25 23:18:46Z dothebart $
+ * $Id: server_main.c 7994 2009-11-02 13:15:52Z davew $
  */
 
 #include "sysdep.h"
@@ -55,7 +55,9 @@
 #include "user_ops.h"
 #include "housekeeping.h"
 #include "svn_revision.h"
-#include "citadel_dirs.c"
+#include "citadel_dirs.h"
+
+#include "context.h"
 
 #include "modules_init.h"
 #include "ecrash.h"
@@ -71,8 +73,6 @@ const char *CitadelServiceUDS="citadel-UDS";
 const char *CitadelServiceTCP="citadel-TCP";
 
 
-extern struct CitContext masterCC;
-
 
 void go_threading(void);
 
@@ -121,6 +121,11 @@ int main(int argc, char **argv)
 			running_as_daemon = 1;
 		}
 
+		/* run a few stats if -s was specified */
+		else if (!strncmp(argv[a], "-s", 2)) {
+			statcount = atoi(&argv[a][2]);
+		}
+
 		/* -x specifies the desired logging level */
 		else if (!strncmp(argv[a], "-x", 2)) {
 			verbosity = atoi(&argv[a][2]);
@@ -155,7 +160,7 @@ int main(int argc, char **argv)
 			CtdlLogPrintf(CTDL_EMERG,	"citserver: usage: "
 					"citserver "
 					"[-lLogFacility] "
-					"[-d] [-D] "
+					"[-d] [-D] [-s]"
 					" [-tTraceFile]"
 					" [-xLogLevel] [-hHomeDir]\n");
 			exit(1);
@@ -262,12 +267,12 @@ int main(int argc, char **argv)
 /**
  * Load the user for the masterCC or create them if they don't exist
  */
-	if (getuser(&masterCC.user, "SYS_Citadel"))
+	if (CtdlGetUser(&masterCC.user, "SYS_Citadel"))
 	{
 		/** User doesn't exist. We can't use create user here as the user number needs to be 0 */
 		strcpy (masterCC.user.fullname, "SYS_Citadel") ;
-		putuser(&masterCC.user);
-		getuser(&masterCC.user, "SYS_Citadel"); /** Just to be safe */
+		CtdlPutUser(&masterCC.user);
+		CtdlGetUser(&masterCC.user, "SYS_Citadel"); /** Just to be safe */
 	}
 	
 	/*
