@@ -1,5 +1,5 @@
 /*
- * $Id: citadel.c 8085 2009-11-25 20:38:42Z ajc $
+ * $Id: citadel.c 8324 2010-02-17 20:03:28Z ajc $
  *
  * Main source module for the client program.
  *
@@ -1691,12 +1691,19 @@ int main(int argc, char **argv)
 	} else {
 		newprompt("\rPlease enter your password: ", password, -19);
 	}
-	strproc(password);
 
 	if (*nonce) {
 		r = CtdlIPCTryApopPassword(ipc, make_apop_string(password, nonce, hexstring, sizeof hexstring), aaa);
+		if (r / 100 != 2) {
+			strproc(password);
+			r = CtdlIPCTryApopPassword(ipc, make_apop_string(password, nonce, hexstring, sizeof hexstring), aaa);
+		}
 	} else {
 		r = CtdlIPCTryPassword(ipc, password, aaa);
+		if (r / 100 != 2) {
+			strproc(password);
+			r = CtdlIPCTryPassword(ipc, password, aaa);
+		}
 	}
 	
 	if (r / 100 == 2) {
