@@ -1,5 +1,5 @@
 /* 
- * $Id: user_ops.c 7211 2009-03-12 15:12:32Z ajc $
+ * $Id: user_ops.c 8032 2009-11-10 19:39:19Z davew $
  *
  * Server functions which perform operations on user objects.
  *
@@ -50,6 +50,10 @@
 #include "citadel_dirs.h"
 #include "genstamp.h"
 #include "threads.h"
+#include "citadel_ldap.h"
+#include "context.h"
+
+#include "ctdl_module.h"
 
 /* These pipes are used to talk to the chkpwd daemon, which is forked during startup */
 int chkpwd_write_pipe[2];
@@ -81,6 +85,16 @@ INLINE void makeuserkey(char *key, char *username) {
  *	       returns 0 on success
  */
 int getuser(struct ctdluser *usbuf, char name[])
+{
+	return CtdlGetUser(usbuf, name);
+}
+
+
+/*
+ * CtdlGetUser()  -  retrieve named user into supplied buffer.
+ *	       returns 0 on success
+ */
+int CtdlGetUser(struct ctdluser *usbuf, char name[])
 {
 
 	char usernamekey[USERNAME_SIZE];
@@ -108,13 +122,13 @@ int getuser(struct ctdluser *usbuf, char name[])
 
 
 /*
- * lgetuser()  -  same as getuser() but locks the record
+ * CtdlGetUserLock()  -  same as getuser() but locks the record
  */
-int lgetuser(struct ctdluser *usbuf, char *name)
+int CtdlGetUserLock(struct ctdluser *usbuf, char *name)
 {
 	int retcode;
 
-	retcode = getuser(usbuf, name);
+	retcode = CtdlGetUser(usbuf, name);
 	if (retcode == 0) {
 		begin_critical_section(S_USERS);
 	}
@@ -123,9 +137,18 @@ int lgetuser(struct ctdluser *usbuf, char *name)
 
 
 /*
- * putuser()  -  write user buffer into the correct place on disk
+ * lgetuser()  -  same as getuser() but locks the record
  */
-void putuser(struct ctdluser *usbuf)
+int lgetuser(struct ctdluser *usbuf, char *name)
+{
+	return CtdlGetUserLock(usbuf, name);
+}
+
+
+/*
+ * CtdlPutUser()  -  write user buffer into the correct place on disk
+ */
+void CtdlPutUser(struct ctdluser *usbuf)
 {
 	char usernamekey[USERNAME_SIZE];
 
@@ -139,13 +162,31 @@ void putuser(struct ctdluser *usbuf)
 }
 
 
+/*
+ * putuser()  -  write user buffer into the correct place on disk
+ */
+void putuser(struct ctdluser *usbuf)
+{
+	CtdlPutUser(usbuf);
+}
+
+
+/*
+ * CtdlPutUserLock()  -  same as putuser() but locks the record
+ */
+void CtdlPutUserLock(struct ctdluser *usbuf)
+{
+	CtdlPutUser(usbuf);
+	end_critical_section(S_USERS);
+}
+
+
 /*
  * lputuser()  -  same as putuser() but locks the record
  */
 void lputuser(struct ctdluser *usbuf)
 {
-	putuser(usbuf);
-	end_critical_section(S_USERS);
+	CtdlPutUserLock(usbuf);
 }
 
 
@@ -156,20 +197,12 @@ void lputuser(struct ctdluser *usbuf)
  *
  */
 int rename_user(char *oldname, char *newname) {
-	struct CitContext *cptr;
 	int retcode = RENAMEUSER_OK;
 	struct ctdluser usbuf;
 
 	char oldnamekey[USERNAME_SIZE];
 	char newnamekey[USERNAME_SIZE];
 
-	/* We cannot rename a user who is currently logged in */
-	for (cptr = ContextList; cptr != NULL; cptr = cptr->next) {
-		if (!strcasecmp(cptr->user.fullname, oldname)) {
-			return(RENAMEUSER_LOGGED_IN);
-		}
-	}
-
 	/* Create the database keys... */
 	makeuserkey(oldnamekey, oldname);
 	makeuserkey(newnamekey, newname);
@@ -177,12 +210,18 @@ int rename_user(char *oldname, char *newname) {
 	/* Lock up and get going */
 	begin_critical_section(S_USERS);
 
-	if (getuser(&usbuf, newname) == 0) {
+	/* We cannot rename a user who is currently logged in */
+	if (CtdlIsUserLoggedIn(oldname)) {
+		end_critical_section(S_USERS);
+		return RENAMEUSER_LOGGED_IN;
+	}
+
+	if (CtdlGetUser(&usbuf, newname) == 0) {
 		retcode = RENAMEUSER_ALREADY_EXISTS;
 	}
 	else {
 
-		if (getuser(&usbuf, oldname) != 0) {
+		if (CtdlGetUser(&usbuf, oldname) != 0) {
 			retcode = RENAMEUSER_NOT_FOUND;
 		}
 
@@ -195,7 +234,7 @@ int rename_user(char *oldname, char *newname) {
 				CtdlLogPrintf(CTDL_DEBUG, "Renaming <%s> to <%s>\n", oldname, newname);
 				cdb_delete(CDB_USERS, oldnamekey, strlen(oldnamekey));
 				safestrncpy(usbuf.fullname, newname, sizeof usbuf.fullname);
-				putuser(&usbuf);
+				CtdlPutUser(&usbuf);
 				cdb_store(CDB_USERSBYNUMBER, &usbuf.usernum, sizeof(long),
 					usbuf.fullname, strlen(usbuf.fullname)+1 );
 
@@ -321,6 +360,12 @@ void CtdlGetRelationship(struct visit *vbuf,
 }
 
 
+void CtdlMailboxName(char *buf, size_t n, const struct ctdluser *who, const char *prefix)
+{
+	snprintf(buf, n, "%010ld.%s", who->usernum, prefix);
+}
+
+
 void MailboxName(char *buf, size_t n, const struct ctdluser *who, const char *prefix)
 {
 	snprintf(buf, n, "%010ld.%s", who->usernum, prefix);
@@ -358,12 +403,12 @@ int is_room_aide(void)
 }
 
 /*
- * getuserbynumber() -	get user by number
+ * CtdlGetUserByNumber() -	get user by number
  * 			returns 0 if user was found
  *
  * Note: fetching a user this way requires one additional database operation.
  */
-int getuserbynumber(struct ctdluser *usbuf, long number)
+int CtdlGetUserByNumber(struct ctdluser *usbuf, long number)
 {
 	struct cdbdata *cdbun;
 	int r;
@@ -375,11 +420,22 @@ int getuserbynumber(struct ctdluser *usbuf, long number)
 	}
 
 	CtdlLogPrintf(CTDL_INFO, "User %ld maps to %s\n", number, cdbun->ptr);
-	r = getuser(usbuf, cdbun->ptr);
+	r = CtdlGetUser(usbuf, cdbun->ptr);
 	cdb_free(cdbun);
 	return(r);
 }
 
+/*
+ * getuserbynumber() -	get user by number
+ * 			returns 0 if user was found
+ *
+ * Note: fetching a user this way requires one additional database operation.
+ */
+int getuserbynumber(struct ctdluser *usbuf, long number)
+{
+	return CtdlGetUserByNumber(usbuf, number);
+}
+
 
 
 /*
@@ -541,13 +597,41 @@ int CtdlLoginExistingUser(char *authname, char *trythisname)
 
 	}
 
+#ifdef HAVE_LDAP
+	else if ((config.c_auth_mode == AUTHMODE_LDAP) || (config.c_auth_mode == AUTHMODE_LDAP_AD)) {
+	
+		/* LDAP auth mode */
+
+		uid_t ldap_uid;
+		char ldap_cn[256];
+		char ldap_dn[256];
+
+		found_user = CtdlTryUserLDAP(username, ldap_dn, sizeof ldap_dn, ldap_cn, sizeof ldap_cn, &ldap_uid);
+		if (found_user != 0) {
+			return login_not_found;
+		}
+
+		found_user = getuserbyuid(&CC->user, ldap_uid);
+		if (found_user != 0) {
+			create_user(trythisname, 0);
+			found_user = getuserbyuid(&CC->user, ldap_uid);
+		}
+
+		if (found_user == 0) {
+			if (CC->ldap_dn != NULL) free(CC->ldap_dn);
+			CC->ldap_dn = strdup(ldap_dn);
+		}
+
+	}
+#endif
+
 	else {
 		/* native auth mode */
 
 		struct recptypes *valid = NULL;
 	
 		/* First, try to log in as if the supplied name is a display name */
-		found_user = getuser(&CC->user, username);
+		found_user = CtdlGetUser(&CC->user, username);
 	
 		/* If that didn't work, try to log in as if the supplied name
 	 	* is an e-mail address
@@ -556,7 +640,7 @@ int CtdlLoginExistingUser(char *authname, char *trythisname)
 			valid = validate_recipients(username, NULL, 0);
 			if (valid != NULL) {
 				if (valid->num_local == 1) {
-					found_user = getuser(&CC->user, valid->recp_local);
+					found_user = CtdlGetUser(&CC->user, valid->recp_local);
 				}
 				free_recipients(valid);
 			}
@@ -586,8 +670,11 @@ void cmd_user(char *cmdbuf)
 	char username[256];
 	int a;
 
+	CtdlLogPrintf(CTDL_DEBUG, "cmd_user(%s)\n", cmdbuf);
 	extract_token(username, cmdbuf, 0, '|', sizeof username);
+	CtdlLogPrintf(CTDL_DEBUG, "username: %s\n", username);
 	striplt(username);
+	CtdlLogPrintf(CTDL_DEBUG, "username: %s\n", username);
 
 	a = CtdlLoginExistingUser(NULL, username);
 	switch (a) {
@@ -623,7 +710,7 @@ void do_login(void)
 	CC->logged_in = 1;
 	CtdlLogPrintf(CTDL_NOTICE, "<%s> logged in\n", CC->curr_user);
 
-	lgetuser(&CC->user, CC->curr_user);
+	CtdlGetUserLock(&CC->user, CC->curr_user);
 	++(CC->user.timescalled);
 	CC->previous_login = CC->user.lastcall;
 	time(&CC->user.lastcall);
@@ -644,7 +731,7 @@ void do_login(void)
 		}
 	}
 
-	lputuser(&CC->user);
+	CtdlPutUserLock(&CC->user);
 
 	/*
 	 * Populate CC->cs_inet_email with a default address.  This will be
@@ -658,15 +745,16 @@ void do_login(void)
 	/* Create any personal rooms required by the system.
 	 * (Technically, MAILROOM should be there already, but just in case...)
 	 */
-	create_room(MAILROOM, 4, "", 0, 1, 0, VIEW_MAILBOX);
-	create_room(SENTITEMS, 4, "", 0, 1, 0, VIEW_MAILBOX);
-	create_room(USERTRASHROOM, 4, "", 0, 1, 0, VIEW_MAILBOX);
+	CtdlCreateRoom(MAILROOM, 4, "", 0, 1, 0, VIEW_MAILBOX);
+	CtdlCreateRoom(SENTITEMS, 4, "", 0, 1, 0, VIEW_MAILBOX);
+	CtdlCreateRoom(USERTRASHROOM, 4, "", 0, 1, 0, VIEW_MAILBOX);
+	/* CtdlCreateRoom(USERDRAFTROOM, 4, "", 0, 1, 0, VIEW_MAILBOX); temporarily disabled for 7.60 */
 
 	/* Run any startup routines registered by loadable modules */
 	PerformSessionHooks(EVT_LOGIN);
 
 	/* Enter the lobby */
-	usergoto(config.c_baseroom, 0, 0, NULL, NULL);
+	CtdlUserGoto(config.c_baseroom, 0, 0, NULL, NULL);
 }
 
 
@@ -686,7 +774,13 @@ void logged_in_response(void)
  */
 void logout(void)
 {
-	struct CitContext *CCC = CC;	/* CachedCitContext - performance boost */
+	CtdlUserLogout();
+}
+
+
+void CtdlUserLogout(void)
+{
+	CitContext *CCC = CC;	/* CachedCitContext - performance boost */
 	/*
 	 * If there is a download in progress, abort it.
 	 */
@@ -737,6 +831,7 @@ void logout(void)
 static int validpw(uid_t uid, const char *pass)
 {
 	char buf[256];
+	int rv = 0;
 
 	if (IsEmptyStr(pass)) {
 		CtdlLogPrintf(CTDL_DEBUG, "refusing to check empty password for uid=%d using chkpwd...\n", uid);
@@ -746,9 +841,9 @@ static int validpw(uid_t uid, const char *pass)
 	CtdlLogPrintf(CTDL_DEBUG, "Validating password for uid=%d using chkpwd...\n", uid);
 
 	begin_critical_section(S_CHKPWD);
-	write(chkpwd_write_pipe[1], &uid, sizeof(uid_t));
-	write(chkpwd_write_pipe[1], pass, 256);
-	read(chkpwd_read_pipe[0], buf, 4);
+	rv = write(chkpwd_write_pipe[1], &uid, sizeof(uid_t));
+	rv = write(chkpwd_write_pipe[1], pass, 256);
+	rv = read(chkpwd_read_pipe[0], buf, 4);
 	end_critical_section(S_CHKPWD);
 
 	if (!strncmp(buf, "PASS", 4)) {
@@ -817,7 +912,7 @@ int CtdlTryPassword(char *password)
 		CtdlLogPrintf(CTDL_WARNING, "CtdlTryPassword: no user selected\n");
 		return pass_no_user;
 	}
-	if (getuser(&CC->user, CC->curr_user)) {
+	if (CtdlGetUser(&CC->user, CC->curr_user)) {
 		CtdlLogPrintf(CTDL_ERR, "CtdlTryPassword: internal error\n");
 		return pass_internal_error;
 	}
@@ -846,9 +941,9 @@ int CtdlTryPassword(char *password)
 			 * this is a security hazard, comment it out.
 			 */
 
-			lgetuser(&CC->user, CC->curr_user);
+			CtdlGetUserLock(&CC->user, CC->curr_user);
 			safestrncpy(CC->user.password, password, sizeof CC->user.password);
-			lputuser(&CC->user);
+			CtdlPutUserLock(&CC->user);
 
 			/*
 			 * (sooper-seekrit hack ends here)
@@ -860,6 +955,20 @@ int CtdlTryPassword(char *password)
 		}
 	}
 
+#ifdef HAVE_LDAP
+	else if ((config.c_auth_mode == AUTHMODE_LDAP) || (config.c_auth_mode == AUTHMODE_LDAP_AD)) {
+
+		/* LDAP auth mode */
+
+		if ((CC->ldap_dn) && (!CtdlTryPasswordLDAP(CC->ldap_dn, password))) {
+			code = 0;
+		}
+		else {
+			code = (-1);
+		}
+	}
+#endif
+
 	else {
 
 		/* native auth mode */
@@ -887,6 +996,7 @@ void cmd_pass(char *buf)
 	char password[256];
 	int a;
 
+	memset(password, 0, sizeof(password));
 	extract_token(password, buf, 0, '|', sizeof password);
 	a = CtdlTryPassword(password);
 
@@ -917,8 +1027,6 @@ int purge_user(char pname[])
 	char filename[64];
 	struct ctdluser usbuf;
 	char usernamekey[USERNAME_SIZE];
-	struct CitContext *ccptr;
-	int user_is_logged_in = 0;
 
 	makeuserkey(usernamekey, pname);
 
@@ -926,7 +1034,7 @@ int purge_user(char pname[])
 	if (IsEmptyStr(pname))
 		return (ERROR + NO_SUCH_USER);
 
-	if (getuser(&usbuf, pname) != 0) {
+	if (CtdlGetUser(&usbuf, pname) != 0) {
 		CtdlLogPrintf(CTDL_ERR, "Cannot purge user <%s> - not found\n", pname);
 		return (ERROR + NO_SUCH_USER);
 	}
@@ -934,22 +1042,24 @@ int purge_user(char pname[])
 	 * set the access level to 0, and let the account get swept up
 	 * during the next purge.
 	 */
-	user_is_logged_in = 0;
-	begin_critical_section(S_SESSION_TABLE);
-	for (ccptr = ContextList; ccptr != NULL; ccptr = ccptr->next) {
-		if (ccptr->user.usernum == usbuf.usernum) {
-			user_is_logged_in = 1;
-		}
-	}
-	end_critical_section(S_SESSION_TABLE);
-	if (user_is_logged_in == 1) {
+	if (CtdlIsUserLoggedInByNum(usbuf.usernum)) {
 		CtdlLogPrintf(CTDL_WARNING, "User <%s> is logged in; not deleting.\n", pname);
 		usbuf.axlevel = 0;
-		putuser(&usbuf);
+		CtdlPutUser(&usbuf);
 		return (1);
 	}
 	CtdlLogPrintf(CTDL_NOTICE, "Deleting user <%s>\n", pname);
 
+/*
+ * FIXME:
+ * This should all be wrapped in a S_USERS mutex.
+ * Without the mutex the user could log in before we get to the next function
+ * That would truly mess things up :-(
+ * I would like to see the S_USERS start before the CtdlIsUserLoggedInByNum() above
+ * and end after the user has been deleted from the database, below.
+ * Question is should we enter the EVT_PURGEUSER whilst S_USERS is active?
+ */
+
 	/* Perform any purge functions registered by server extensions */
 	PerformUserHooks(&usbuf, EVT_PURGEUSER);
 
@@ -984,7 +1094,7 @@ int purge_user(char pname[])
 
 int internal_create_user (char *username, struct ctdluser *usbuf, uid_t uid)
 {
-	if (!getuser(usbuf, username)) {
+	if (!CtdlGetUser(usbuf, username)) {
 		return (ERROR + ALREADY_EXISTS);
 	}
 
@@ -1008,7 +1118,7 @@ int internal_create_user (char *username, struct ctdluser *usbuf, uid_t uid)
 	usbuf->usernum = get_new_user_number();
 
 	/* add user to the database */
-	putuser(usbuf);
+	CtdlPutUser(usbuf);
 	cdb_store(CDB_USERSBYNUMBER, &usbuf->usernum, sizeof(long), usbuf->fullname, strlen(usbuf->fullname)+1);
 
 	return 0;
@@ -1067,6 +1177,14 @@ int create_user(char *newusername, int become_user)
 			return (ERROR + NO_SUCH_USER);
 		}
 	}
+
+#ifdef HAVE_LDAP
+	if ((config.c_auth_mode == AUTHMODE_LDAP) || (config.c_auth_mode == AUTHMODE_LDAP_AD)) {
+		if (CtdlTryUserLDAP(username, NULL, 0, username, sizeof username, &uid) != 0) {
+			return(ERROR + NO_SUCH_USER);
+		}
+	}
+#endif /* HAVE_LDAP */
 	
 	if ((retval = internal_create_user(username, &usbuf, uid)) != 0)
 		return retval;
@@ -1075,14 +1193,14 @@ int create_user(char *newusername, int become_user)
 	 * Give the user a private mailbox and a configuration room.
 	 * Make the latter an invisible system room.
 	 */
-	MailboxName(mailboxname, sizeof mailboxname, &usbuf, MAILROOM);
-	create_room(mailboxname, 5, "", 0, 1, 1, VIEW_MAILBOX);
+	CtdlMailboxName(mailboxname, sizeof mailboxname, &usbuf, MAILROOM);
+	CtdlCreateRoom(mailboxname, 5, "", 0, 1, 1, VIEW_MAILBOX);
 
-	MailboxName(mailboxname, sizeof mailboxname, &usbuf, USERCONFIGROOM);
-	create_room(mailboxname, 5, "", 0, 1, 1, VIEW_BBS);
-	if (lgetroom(&qrbuf, mailboxname) == 0) {
+	CtdlMailboxName(mailboxname, sizeof mailboxname, &usbuf, USERCONFIGROOM);
+	CtdlCreateRoom(mailboxname, 5, "", 0, 1, 1, VIEW_BBS);
+	if (CtdlGetRoomLock(&qrbuf, mailboxname) == 0) {
 		qrbuf.QRflags2 |= QR2_SYSTEM;
-		lputroom(&qrbuf);
+		CtdlPutRoomLock(&qrbuf);
 	}
 
 	/* Perform any create functions registered by server extensions */
@@ -1099,7 +1217,7 @@ int create_user(char *newusername, int become_user)
 		do_login();
 	
 		/* Check to make sure we're still who we think we are */
-		if (getuser(&CC->user, CC->curr_user)) {
+		if (CtdlGetUser(&CC->user, CC->curr_user)) {
 			return (ERROR + INTERNAL_ERROR);
 		}
 	}
@@ -1110,7 +1228,7 @@ int create_user(char *newusername, int become_user)
 		CC->cs_host,
 		CC->cs_addr
 	);
-	aide_message(buf, "User Creation Notice");
+	CtdlAideMessage(buf, "User Creation Notice");
 	CtdlLogPrintf(CTDL_NOTICE, "New user <%s> created\n", username);
 	return (0);
 }
@@ -1185,9 +1303,9 @@ void cmd_newu(char *cmdbuf)
  */
 void CtdlSetPassword(char *new_pw)
 {
-	lgetuser(&CC->user, CC->curr_user);
+	CtdlGetUserLock(&CC->user, CC->curr_user);
 	safestrncpy(CC->user.password, new_pw, sizeof(CC->user.password));
-	lputuser(&CC->user);
+	CtdlPutUserLock(&CC->user);
 	CtdlLogPrintf(CTDL_INFO, "Password changed for user <%s>\n", CC->curr_user);
 	PerformSessionHooks(EVT_SETPASS);
 }
@@ -1262,9 +1380,9 @@ void cmd_creu(char *cmdbuf)
 
 	if (a == 0) {
 		if (!IsEmptyStr(password)) {
-			lgetuser(&tmp, username);
+			CtdlGetUserLock(&tmp, username);
 			safestrncpy(tmp.password, password, sizeof(tmp.password));
-			lputuser(&tmp);
+			CtdlPutUserLock(&tmp);
 		}
 		cprintf("%d User '%s' created %s.\n", CIT_OK, username,
 				(!IsEmptyStr(password)) ? "and password set" :
@@ -1287,13 +1405,13 @@ void cmd_creu(char *cmdbuf)
 /*
  * get user parameters
  */
-void cmd_getu(void)
+void cmd_getu(char *cmdbuf)
 {
 
 	if (CtdlAccessCheck(ac_logged_in))
 		return;
 
-	getuser(&CC->user, CC->curr_user);
+	CtdlGetUser(&CC->user, CC->curr_user);
 	cprintf("%d %d|%d|%d|\n",
 		CIT_OK,
 		CC->user.USscreenwidth,
@@ -1314,14 +1432,14 @@ void cmd_setu(char *new_parms)
 		cprintf("%d Usage error.\n", ERROR + ILLEGAL_VALUE);
 		return;
 	}
-	lgetuser(&CC->user, CC->curr_user);
+	CtdlGetUserLock(&CC->user, CC->curr_user);
 	CC->user.USscreenwidth = extract_int(new_parms, 0);
 	CC->user.USscreenheight = extract_int(new_parms, 1);
 	CC->user.flags = CC->user.flags & (~US_USER_SET);
 	CC->user.flags = CC->user.flags |
 	    (extract_int(new_parms, 2) & US_USER_SET);
 
-	lputuser(&CC->user);
+	CtdlPutUserLock(&CC->user);
 	cprintf("%d Ok\n", CIT_OK);
 }
 
@@ -1344,7 +1462,7 @@ void cmd_slrp(char *new_ptr)
 		newlr = atol(new_ptr);
 	}
 
-	lgetuser(&CC->user, CC->curr_user);
+	CtdlGetUserLock(&CC->user, CC->curr_user);
 
 	CtdlGetRelationship(&vbuf, &CC->user, &CC->room);
 	memcpy(&original_vbuf, &vbuf, sizeof(struct visit));
@@ -1357,7 +1475,7 @@ void cmd_slrp(char *new_ptr)
 		CtdlSetRelationship(&vbuf, &CC->user, &CC->room);
 	}
 
-	lputuser(&CC->user);
+	CtdlPutUserLock(&CC->user);
 	cprintf("%d %ld\n", CIT_OK, newlr);
 }
 
@@ -1407,7 +1525,7 @@ int CtdlInvtKick(char *iuser, int op) {
 	struct visit vbuf;
 	char bbb[SIZ];
 
-	if (getuser(&USscratch, iuser) != 0) {
+	if (CtdlGetUser(&USscratch, iuser) != 0) {
 		return(1);
 	}
 
@@ -1428,7 +1546,7 @@ int CtdlInvtKick(char *iuser, int op) {
 		((op == 1) ? "invited to" : "kicked out of"),
 		CC->room.QRname,
 		CC->user.fullname);
-	aide_message(bbb,"User Admin Message");
+	CtdlAideMessage(bbb,"User Admin Message");
 
 	return(0);
 }
@@ -1472,6 +1590,8 @@ void cmd_invt_kick(char *iuser, int op) {
 	return;
 }
 
+void cmd_invt(char *iuser) {cmd_invt_kick(iuser, 1);}
+void cmd_kick(char *iuser) {cmd_invt_kick(iuser, 0);}
 
 /*
  * Forget (Zap) the current room (API call)
@@ -1486,17 +1606,17 @@ int CtdlForgetThisRoom(void) {
 		return(1);
 	}
 
-	lgetuser(&CC->user, CC->curr_user);
+	CtdlGetUserLock(&CC->user, CC->curr_user);
 	CtdlGetRelationship(&vbuf, &CC->user, &CC->room);
 
 	vbuf.v_flags = vbuf.v_flags | V_FORGET;
 	vbuf.v_flags = vbuf.v_flags & ~V_ACCESS;
 
 	CtdlSetRelationship(&vbuf, &CC->user, &CC->room);
-	lputuser(&CC->user);
+	CtdlPutUserLock(&CC->user);
 
 	/* Return to the Lobby, so we don't end up in an undefined room */
-	usergoto(config.c_baseroom, 0, 0, NULL, NULL);
+	CtdlUserGoto(config.c_baseroom, 0, 0, NULL, NULL);
 	return(0);
 
 }
@@ -1505,7 +1625,7 @@ int CtdlForgetThisRoom(void) {
 /*
  * forget (Zap) the current room
  */
-void cmd_forg(void)
+void cmd_forg(char *argbuf)
 {
 
 	if (CtdlAccessCheck(ac_logged_in)) {
@@ -1523,7 +1643,7 @@ void cmd_forg(void)
 /*
  * Get Next Unregistered User
  */
-void cmd_gnur(void)
+void cmd_gnur(char *argbuf)
 {
 	struct cdbdata *cdbus;
 	struct ctdluser usbuf;
@@ -1586,7 +1706,7 @@ void cmd_vali(char *v_args)
 		return;
 	}
 
-	if (lgetuser(&userbuf, user) != 0) {
+	if (CtdlGetUserLock(&userbuf, user) != 0) {
 		cprintf("%d '%s' not found.\n", ERROR + NO_SUCH_USER, user);
 		return;
 	}
@@ -1594,7 +1714,7 @@ void cmd_vali(char *v_args)
 	userbuf.axlevel = newax;
 	userbuf.flags = (userbuf.flags & ~US_NEEDVALID);
 
-	lputuser(&userbuf);
+	CtdlPutUserLock(&userbuf);
 
 	/* If the access level was set to zero, delete the user */
 	if (newax == 0) {
@@ -1676,7 +1796,7 @@ void cmd_list(char *cmdbuf)
 /*
  * assorted info we need to check at login
  */
-void cmd_chek(void)
+void cmd_chek(char *argbuf)
 {
 	int mail = 0;
 	int regis = 0;
@@ -1686,7 +1806,7 @@ void cmd_chek(void)
 		return;
 	}
 
-	getuser(&CC->user, CC->curr_user);	/* no lock is needed here */
+	CtdlGetUser(&CC->user, CC->curr_user);	/* no lock is needed here */
 	if ((REGISCALL != 0) && ((CC->user.flags & US_REGIS) == 0))
 		regis = 1;
 
@@ -1710,7 +1830,7 @@ void cmd_qusr(char *who)
 {
 	struct ctdluser usbuf;
 
-	if (getuser(&usbuf, who) == 0) {
+	if (CtdlGetUser(&usbuf, who) == 0) {
 		cprintf("%d %s\n", CIT_OK, usbuf.fullname);
 	} else {
 		cprintf("%d No such user.\n", ERROR + NO_SUCH_USER);
@@ -1731,7 +1851,7 @@ void cmd_agup(char *cmdbuf)
 	}
 
 	extract_token(requested_user, cmdbuf, 0, '|', sizeof requested_user);
-	if (getuser(&usbuf, requested_user) != 0) {
+	if (CtdlGetUser(&usbuf, requested_user) != 0) {
 		cprintf("%d No such user.\n", ERROR + NO_SUCH_USER);
 		return;
 	}
@@ -1766,7 +1886,7 @@ void cmd_asup(char *cmdbuf)
 		return;
 
 	extract_token(requested_user, cmdbuf, 0, '|', sizeof requested_user);
-	if (lgetuser(&usbuf, requested_user) != 0) {
+	if (CtdlGetUserLock(&usbuf, requested_user) != 0) {
 		cprintf("%d No such user.\n", ERROR + NO_SUCH_USER);
 		return;
 	}
@@ -1791,7 +1911,7 @@ void cmd_asup(char *cmdbuf)
 	if (np > 8) {
 		usbuf.USuserpurge = extract_int(cmdbuf, 8);
 	}
-	lputuser(&usbuf);
+	CtdlPutUserLock(&usbuf);
 	if (usbuf.axlevel == 0) {
 		if (purge_user(requested_user) == 0) {
 			deleted = 1;
@@ -1802,7 +1922,7 @@ void cmd_asup(char *cmdbuf)
 		snprintf(notify, SIZ, 
 			 "User \"%s\" has been deleted by %s.\n",
 			 usbuf.fullname, CC->user.fullname);
-		aide_message(notify, "User Deletion Message");
+		CtdlAideMessage(notify, "User Deletion Message");
 	}
 
 	cprintf("%d Ok", CIT_OK);
@@ -1813,26 +1933,6 @@ void cmd_asup(char *cmdbuf)
 
 
 
-/*
- * Check to see if the user who we just sent mail to is logged in.  If yes,
- * bump the 'new mail' counter for their session.  That enables them to
- * receive a new mail notification without having to hit the database.
- */
-void BumpNewMailCounter(long which_user) {
-	struct CitContext *ptr;
-
-	begin_critical_section(S_SESSION_TABLE);
-
-	for (ptr = ContextList; ptr != NULL; ptr = ptr->next) {
-		if (ptr->user.usernum == which_user) {
-			ptr->newmail += 1;
-		}
-	}
-
-	end_critical_section(S_SESSION_TABLE);
-}
-
-
 /*
  * Count the number of new mail messages the user has
  */
@@ -1861,8 +1961,8 @@ int InitialMailCheck()
 	long *msglist = NULL;
 	int num_msgs = 0;
 
-	MailboxName(mailboxname, sizeof mailboxname, &CC->user, MAILROOM);
-	if (getroom(&mailbox, mailboxname) != 0)
+	CtdlMailboxName(mailboxname, sizeof mailboxname, &CC->user, MAILROOM);
+	if (CtdlGetRoom(&mailbox, mailboxname) != 0)
 		return (0);
 	CtdlGetRelationship(&vbuf, &CC->user, &mailbox);
 
@@ -1946,3 +2046,40 @@ void cmd_renu(char *cmdbuf)
 
 	cprintf("%d An unknown error occurred.\n", ERROR);
 }
+
+
+
+/*****************************************************************************/
+/*                      MODULE INITIALIZATION STUFF                          */
+/*****************************************************************************/
+
+
+CTDL_MODULE_INIT(user_ops)
+{
+	if (!threading) {
+		CtdlRegisterProtoHook(cmd_user, "USER", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_pass, "PASS", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_creu, "CREU", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_setp, "SETP", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_getu, "GETU", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_setu, "SETU", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_slrp, "SLRP", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_invt, "INVT", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_kick, "KICK", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_forg, "FORG", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_gnur, "GNUR", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_vali, "VALI", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_list, "LIST", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_chek, "CHEK", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_qusr, "QUSR", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_agup, "AGUP", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_asup, "ASUP", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_seen, "SEEN", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_gtsn, "GTSN", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_view, "VIEW", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_renu, "RENU", "Autoconverted. TODO: document me.");
+		CtdlRegisterProtoHook(cmd_newu, "NEWU", "Autoconverted. TODO: document me.");
+	}
+	/* return our Subversion id for the Log */
+	return "$Id: user_ops.c 8032 2009-11-10 19:39:19Z davew $";
+}
