@@ -1,5 +1,5 @@
 /*
- * $Id: setup.c 8061 2009-11-18 15:43:46Z ajc $
+ * $Id: setup.c 8324 2010-02-17 20:03:28Z ajc $
  *
  * Citadel setup utility
  *
@@ -925,6 +925,9 @@ void edit_value(int curr)
 		}
 		else
 		{
+			if (config.c_ldap_port == 0) {
+				config.c_ldap_port = 389;
+			}
 			set_int_val(curr, &config.c_ldap_port);
 		}
 		break;
